Contributing Code
=================

In the past Karaage was current developed using
`Gerrit <https://code.vpac.org/gerrit>`_. 
As of 2015-06-19 this is no longer the case. github pull requests should be
used instead.


Getting Started
---------------

#.  Checkout the latest version of Karaage:

    .. code-block:: bash

        git clone https://github.com/Karaage-Cluster/karaage.git
        cd karaage

    You can test that you've setup the commit-msg script correctly by doing a
    commit and then looking at the log. You should see a "Change-Id: I[hex]"
    line show up in your commit message text.

#.  Make changes, commit, and submit as github pull request.
